pub enum Action {
Start,
Upload,
Hide,
Folder,
Unknown(String),
}Variants
Start
start means that a large file has been started, but not finished or canceled.
Upload
upload means a file that was uploaded to B2 Cloud Storage.
Hide
hide means a file version marking the file as hidden, so that it will not show up in b2_list_file_names.
Folder
folder is used to indicate a virtual folder when listing files.
Unknown(String)
Untagged action.